---
title: 'Subscription management'
linkTitle: 'Subscription management'
weight: 2
description: 'How to manage your subscription'
---

This article provides tips on how to effectively manage your
CVAT subscriptions, including tracking expenses and canceling
unnecessary subscriptions, to optimize your finances and save time.

Whether you're a business owner or an individual,
you'll learn how to take control of your subscriptions and manage them.

See:

- [Available paid plans](#available-paid-plans)
  - [Monthly plans](#monthly-plans)
  - [Annual plans](#annual-plans)
- [Billing](#billing)
  - [How to add VAT/tax and other information to the CVAT.ai invoice before the first payment?](#how-to-add-vattax-and-other-information-to-the-cvatai-invoice-before-the-first-payment)
  - [How to update VAT/tax information and other details for upcoming invoices from CVAT.ai?](#how-to-update-vattax-information-and-other-details-for-upcoming-invoices-from-cvatai)
  - [Can a paid invoice be modified?](#can-a-paid-invoice-be-modified)
  - [How can I get a quote before I subscribe? How to add a PO number to my invoices?](#how-can-i-get-a-quote-before-i-subscribe-how-to-add-a-po-number-to-my-invoices)
  - [Can you sign an agreement before I subscribe?](#can-you-sign-an-agreement-before-i-subscribe)
  - [Can you handle a bank transfer with 30-day payment terms?](#can-you-handle-a-bank-transfer-with-30-day-payment-terms)
  - [Where can I find my invoices?](#where-can-i-find-my-invoices)
  - [I am a student, can I have a discount or free access?](#i-am-a-student-can-i-have-a-discount-or-free-access)
- [Payment methods](#payment-methods)
  - [Paying with bank transfer](#paying-with-bank-transfer)
  - [How to change the payment method?](#how-to-change-the-payment-method)
- [Adding and removing team members](#adding-and-removing-team-members)
- [Change plan](#change-plan)
  - [How to change the plan from Solo to Team?](#how-to-change-the-plan-from-solo-to-team)
  - [How to switch from a monthly subscription to an annual one?](#how-to-switch-from-a-monthly-subscription-to-an-annual-one)
- [Can I subscribe to several plans?](#can-i-subscribe-to-several-plans)
- [Cancel plan](#cancel-plan)
  - [What will happen to my data?](#what-will-happen-to-my-data)
  - [How to cancel any plan?](#how-to-cancel-any-plan)
  - [How can I get a refund?](#how-can-i-get-a-refund)
- [Plan renewal](#plan-renewal)
- [Subscription management video tutorial](#subscription-management-video-tutorial)

## Available paid plans

This section outlines the paid plans available on CVAT.ai.

### Monthly plans

<!--lint disable maximum-line-length-->

| Name     | Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| -------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| **Solo** | The **Solo** plan has a fixed price and is designed **for personal use only**. <br><br>It does not assume collaboration with team members and is not suitable for use within organizations, but it removes all other limitations of the **Free** plan. <Br><br> **Note**: Although it allows the creation of an organization and access for up to 2 members -- it is _for trial purposes_ only! <br>Organization and members _will have all the limitations of the **Free** plan_.                           |
| **Team** | The **Team** is **for collaboration**, it removes limitations of the **Free** plan for the whole organization, allowing you to share paid benefits with your colleagues. <br><br>The **monthly payment for the plan depends on the number of team members you've added**. All limits of the **Free** plan will be removed. <Br><br> **Note**: The organization owner is also part of the team. So, if you have two annotators working, you'll need to pay for 3 seats (2 annotators + 1 organization owner). |

<!--lint enable maximum-line-length-->

### Annual plans

Whether you're a new user, or have a subscription to **Team** or **Solo** plan, [you can
subscribe to our annual plan](https://www.cvat.ai/post/cvat-annual-plans)
and save up to 30% on CVAT.ai usage costs.

The annual subscription offers all the benefits of our paid plans but at
a more affordable monthly rate.

For more information, see [How to switch from monthly subscription to annual?](#how-to-switch-from-monthly-subscription-to-annual)

## Billing

This section describes the billing model and gives short a
description of limitations for each plan.

There are two types of subscriptions available for both the Solo
and Team plans: monthly and annual.

For more information,
see: [Pricing Plans](https://www.cvat.ai/post/new-pricing-plans)

### How to add VAT/tax and other information to the CVAT.ai invoice before the first payment?

To ensure VAT (tax) information and other relevant details are included on your CVAT.ai invoices,
it's important to add this information before making the first payment.

Here’s how you can do it:

1. Sign up for a CVAT.ai account and log in.
2. (Optional) If you add the VAT/tax number to the organization,
   first create an [organization](/docs/manual/advanced/organization/) and
   switch to an **Organization** account.
3. Navigate to the top right corner, next to the nickname,
   click on the arrow > upgrade to the plan.
4. Switch on the **I would like the invoice to include additional
   data (address, phone number, VAT information)** toggle, select the
   best payment period for you, and click **Get Started**.

![Stripe Link](/images/add-invoice.png)

5. You will see the billing page:

![Stripe Link](/images/add-vat.png)

- Phone number **(1)**.
- **Billing Address**: Enter the billing address you want to appear on the invoice
     in the address field **(2)**.
- **VAT Information** and **Business Name**: Select the checkbox **I am purchasing as a business** and enter
  your VAT and business name information **(3)**.

6. Select checkbox **I agree to refund policy** **(4)**.

   > **Note:** Please read the **Refund policy** before selecting the checkbox.

7. Click **Pay & Subscribe**.

All information you've added will appear on the billing page and in the invoice.

![Stripe Payment Info](/images/sm-profile-upd-inf.png)

By following these steps, you can seamlessly add VAT and other crucial information to your
invoices, making your financial transactions with CVAT.ai transparent and compliant.

### How to update VAT/tax information and other details for upcoming invoices from CVAT.ai?

In the top right corner, near the nickname, click on the arrow > manage plan.

You will see the Stripe page. Go to the **Billing Information** > **Update Information**.

![Stripe Payment Info](/images/sm-profile-upd-inf-2.png)

### Can a paid invoice be modified?

Once an invoice has been paid, it is not possible to modify it. This restriction is due to the
limitations of the payment processing platform used, which in the case of CVAT.ai, is [Stripe](https://stripe.com/).

Stripe's policy dictates that revisions to an invoice can only be made before payment.
For more comprehensive information on this policy, please refer to Stripe's official documentation
on [invoice edits](https://docs.stripe.com/invoicing/invoice-edits#:~:text=Stripe%20lets%20you%20revise%20a,Edit%20the%20invoice%20description.)
at their website.

### How can I get a quote before I subscribe? How to add a PO number to my invoices?

If you require a quote from CVAT for payment via bank transfer, certain criteria must be met:

- The **total subscription cost must be $396 and up per year**.
- Quotes are available exclusively **for annual subscriptions**.

Should you meet these requirements, please write to [support@cvat.ai](mailto:support@cvat.ai)

### Can you sign an agreement before I subscribe?

Sign of specific agreements and approvals are available if you meet specific criteria
(the **total subscription cost must be $10,000 and up per year**), for more details contact [support@cvat.ai](mailto:support@cvat.ai)

### Can you handle a bank transfer with 30-day payment terms?

Yes, it is available if you fit the quota criteria, for details contact [support@cvat.ai](mailto:support@cvat.ai).

### Where can I find my invoices?

In the top right corner, near the nickname, click on the arrow > manage plan.

You will see the Stripe page.
At the bottom of the page, you will see the **Invoice History** section with all invoices.

Invoices are automatically sent to the account owner's address used for the registration.

To see the invoice click on the **Show Invoice Icon**![Stripe Invoice Icon](/images/invoice-icon.png) icon.

![Show Invoice](/images/show-invoice.png)

### I am a student, can I have a discount or free access?

To consider your request for a discount, we'd need a few details from you:

- A copy of your valid student ID or any document confirming your university affiliation.
- Your university advisor's contact details.
- The name and contact information of the dean of your faculty.
- A brief outline of your project plan. This helps us understand how we might collaborate
   on a joint marketing statement highlighting your use of CVAT.ai, and how it can benefit your project.
- We'd also appreciate a positive LinkedIn post about your experience using CVAT, making sure to tag @CVAT.ai.

All these details must be sent to [support@cvat.ai](mailto:support@cvat.ai). Once we have this
information, we'll gladly offer you a 50% discount for one year.

## Payment methods

This section describes how to change or add payment methods.

### Paying with bank transfer

> **Note** At the moment this method of payment
> works only with US banks.

To pay with a bank transfer:

1. Go to the **Upgrade to Solo**/**Team plan**> **Get started**.
2. Click **US Bank Transfer**.
3. Upon successful completion of the payment, you will receive a receipt via email.

> **Note** that the completion of the payment process may take up to three banking days.

![Bank Transfer Payment](/images/bank_transfer_payment.png)

### How to change the payment method?

In the top right corner, near the nickname, click on the arrow > manage plan > **+Add Payment Method**

![Payment team](/images/update_payment_team.png)

## Adding and removing team members

> **Solo plan** is **for personal use only**, you cannot add or remove team members.

**Team plan** is for collaboration. To add members to your [Organization](/docs/manual/advanced/organization/),
go to the **Manage Team plan** > **Update quantity**.

![Add members](/images/change_members_number_team.gif)

If you've added a user **before the current billing period ends**,
the payment will be prorated for the remaining time until the
next billing cycle begins. From the following month onward,
the full payment will be charged.

In case you **removed the user before the current billing period ends**,
funds will not be returned to your account,
but next month you will pay less by the amount of unused funds.

## Change plan

### How to change the plan from Solo to Team?

The procedure is the same for both **Solo** and **Team** plans.

If for some reason you want to change your plan, you need to:

1. Unsubscribe from the previous plan.
2. If you need a refund, contact us at [support@cvat.ai](mailto:support@cvat.ai).
3. Subscribe to a new plan.

### How to switch from a monthly subscription to an annual one?

If you have **monthly subscription**, and wish to switch to the
**Annual plan**, please follow these steps:

1. In the top-right corner, near the nickname, click on the arrow.
2. Select **Manage Solo**/**Team Plan**.
3. On the Stripe page that appears, click **Update Plan**.

![Stripe Update Plan](/images/switch-to-annual.png)

4. Choose **Yearly** and then click **Continue**.

![Stripe Yearly Plan](/images/yearly-plan.png)

The price will be adjusted according to the number of members, selected in the
**Quantity** field (if updated), taking into account the amount of money
that was not spent in the current period.

Upon payment, your subscription will be renewed and the start
date will be reset to the day you switch to the new plan.

## Can I subscribe to several plans?

Paid plans are not mutually exclusive.
You can have several active subscriptions,
for example, the **Solo** plan and several **Team**
plans for different organizations.

## Cancel plan

This section describes how to cancel your CVAT subscription
and what will happen to your data.

### What will happen to my data?

Once you have terminated your subscription, your data will remain
accessible within the system for a month. During this period,
you will be unable to add new tasks and free plan limits will be applied.

In case you possess a substantial amount of data,
it will be switched to read-only mode. It means
you will not be able to save annotations, add any resources,
and so on.

Following the one month, you will receive a
notification requesting you to either remove the
excess data or it will be deleted automatically.

### How to cancel any plan?

To cancel the plan, in the top right corner, near the nickname,
click on the arrow> manage plan > **Cancel plan**

Please, fill out the feedback form, to help us improve our platform.

![Cancel pro](/images/cancel-plan.png)

### How can I get a refund?

To understand if you are eligible for a refund,
see [Refund policy](https://www.cvat.ai/refund-policy).

1. Cancel the subscription before asking for a refund.
2. Contact our support team at [support@cvat.ai](mailto:support@cvat.ai)
   or use the "Support" option in the app.cvat.ai interface.
3. Provide your account details and a brief explanation of the reason for the refund:
   - Send us your last invoice.
   - Send us the username and e-mail address you’ve used to register in CVAT.ai.

Our team will review your request. We may request additional information if needed.
Once approved, the refund will be processed to your original
payment method [within 5-10 business days](https://docs.stripe.com/refunds#tracing-refunds).

## Plan renewal

To renew your CVAT.ai subscription, in the top right corner, near the nickname,
click on the arrow> manage plan > **Renew plan**.

## Subscription management video tutorial

<!--lint disable maximum-line-length-->

<iframe width="560" height="315" src="https://www.youtube.com/embed/AMPtbmqZKNY?si=2TLhdytDIlSJ3Fwd" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>

<!--lint enable maximum-line-length-->
